.. :changelog:

History
-------


0.6.0 (2015-06-14)
---------------------
* Make tifffile a package, fix handling of _tifffile.c files


0.4.0 (2014-12-13)
---------------------
* Do not require importlib to use tifffile.c
* Fix SSIZE_MAX bug for mingw


0.3.0 (2014-10-12)
---------------------
* Install as a top-level python and compiled file.


0.2.0 (2014-10-12)
---------------------
* Add __version__ attribute and update PyPI classifiers.


0.1.0 (2014-10-11)
---------------------

* First release on PyPI.
